ChatAgent class

Constructors

ChatAgent()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

userCacheSize int
no setter
userMessageQueueSize int
no setter

Static Methods

checkUserMessage(String userId, String message) ValidateResult
getUserMsgQueue(String userId) FixedSizeQueue<String>?
initialize(int userMessageQueueSize, int userCacheSize) Future<void>