Validator class

Constructors

Validator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

alphaNumericRegExp RegExp
getter/setter pair
homophoneMap Map<String, String>
////////////////数字同音字字典///////////
final
nonChinesePattern RegExp
getter/setter pair
warnRegExp RegExp
final

Constants

addPattern → const String
alphaNumericPattern → const String
/////////////用于检测的正则表达式/////////////
qqPattern → const String
vqPattern → const String
wechatPattern → const String