FixedSizeQueue<T> class

Constructors

FixedSizeQueue(int maxSize)

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
isFull bool
no setter
items List<T>
no setter
lastModified DateTime
no setter
maxSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dequeue() → T?
enqueue(T item) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited